pub fn schema_hash(schema: &Value) -> StringExpand description
Compute a SHA-256 hash of a schema Value.
Call this once per schema group and pass the result to
ValidationCache::lookup and ValidationCache::store.
pub fn schema_hash(schema: &Value) -> StringCompute a SHA-256 hash of a schema Value.
Call this once per schema group and pass the result to
ValidationCache::lookup and ValidationCache::store.